﻿
@font-face {
    font-family: tesco;
    src: url(/customer/fonts/TESCOModern-Regular-web.eot);
    src: url(/customer/fonts/TESCOModern-Regular-web.eot?#iefix) format("embedded-opentype"), url(/customer/fonts/fonts/TESCOModern-Regular-web.woff) format("woff"), url(/customer/fonts/fonts/TESCOModern-Regular-web.ttf) format("truetype"), url(/customer/fonts/fonts/TESCOModern-Regular-web.svg) format("svg");
    font-weight: 400
}

@font-face {
    font-family: tesco;
    src: url(/customer/fonts/TESCOModern-Bold-web.eot);
    src: url(/customer/fonts/tescodisbol-webfont.48b092ec06f824a19102.eot?#iefix) format("embedded-opentype"), url(/customer/fonts/fonts/TESCOModern-Bold-web.woff) format("woff"), url(/customer/fonts/fonts/TESCOModern-Bold-web.ttf) format("truetype"), url(/customer/fonts/fonts/TESCOModern-Bold-web.svg) format("svg");
    font-weight: 700
}

.breadcrumb,
.breadcrumb[_ngcontent-c3] {
    background: transparent !important;
}

.page-content {
    background: #f6f6f6 !important;
}

.online-safety {
    padding: 0 10px;
    h1, h2, h3, h4, h5, h6, p, ul, li, a, button {
         font-family: 'tesco', Tahoma,sans-serif !important;
    }
}
@media (max-width: 768px) {
    .online-safety {
        
         padding: 0 15px;
    }
}

.online-safety a[target=_blank] {
/*    margin-right:16px;*/
}
.online-safety a[target=_blank]::after {
    content:'';
    display: inline-block;
    width: 16px;
    height: 16px;
    background-image: url(/customer/resources/images/online-safety/quill_link-out.svg);
    background-repeat: no-repeat;
    background-position: center;
    margin-bottom: -2px;
}

.online-safety__h1-style {
    text-align: center;
    color: #575252;
    font-weight: 700;
    font-size: 32px;
    line-height: 36px;
    margin-bottom: 16px;
    margin-top: 30px;
}

.online-safety__h2-style {
    text-align: center;
    font-weight: 700;
    font-size: 24px;
    line-height: 28px;
    margin-bottom: 16px;
    margin-top: 24px;
}

.online-safety__h3-style {
    text-align: center;
    font-weight: 700;
    font-size: 24px;
    line-height: 28px;
    margin-bottom: 16px;
    margin-top: 40px;
}

.online-safety__p-regular {
    text-align: center;
    font-weight: 400px;
    font-size: 16px;
    line-height: 24px;
}

.online-safety__p-regular--left.online-safety__p-regular {
    text-align: center;
}

@media (min-width: 768px) {
    .online-safety__p-regular--left.online-safety__p-regular {
        text-align: left; 
    }
}



.online-safety__device-select__subheading {
    text-align:center;
    margin-bottom: 16px;
}

.online-safety__cards {
    margin-bottom:20px;
    display: flex;
    flex-direction: column;
    gap: 20px;
}
@media (min-width: 768px) {
    .online-safety__cards {
        flex-direction: row;
        gap: initial;
    }
}

.online-safety__card {
    width: 100%;
    display: flex;
    background: white;
    box-sizing:border-box;
    padding: 16px;
    border-radius: 4px;
    box-shadow: 0px 2px 4px 0px #00000026;
    border: 2px solid white;
}
.online-safety__card:hover,
.online-safety__card:focus {
}

.online-safety__card__icon__image-for-phone {
    display: initial;
    visibility: initial;
}
.online-safety__card__icon__image-for-desktop {
    display: none;
    visibility: hidden;
}

.online-safety__card__icon img {
    max-width: 100%;
    max-height: 100%;
}

.online-safety__card__content {
    display: flex;
    text-align: right;
    flex-direction: column;
    justify-content: space-around;
    margin-left: auto
}

.online-safety__card__heading {
    color: #00539f;
    font-size: 20px;
    line-height: 24px;
    font-weight: 700;
    margin: 0;
}

.online-safety__card__subheading {
    color: #575252;
    font-size: 16px;
    line-height: 24px;
    font-weight: 400;
    margin: 0;
    margin-bottom: -24px;
}
@media (max-width: 374px) {
    .online-safety__card__subheading.online-safety__subheading--extra-long-text {
        margin-bottom: auto !important;
    }
}

.online-safety__card--selected {
    border: 2px solid #00539f;
    box-shadow: 0px 0px 0 2px #00539f66 !important;
}

.online-safety__device-select {
    width: 100%;
    max-width: 606px;
    margin: 0 auto;
}

.online-safety__device-select--2cards {
    max-width: 606px;
}

.online-safety__device-select--3cards {
    max-width: 880px;
}

@media (min-width: 768px) {
    
    .online-safety__cards {
        flex-direction:row;
        gap: 24px;
        margin-bottom: 48px;
    }
    
    .online-safety__card {
        padding:24px 16px 32px 16px;
        width: 291px;
        height: 267px;
        box-sizing: border-box;
        flex-direction: column-reverse;
    }
    
    .online-safety__card__content {
        
        width:100%;
        text-align: left;
        padding-top: 23px;
    }
    
    .online-safety__card__icon {
        margin: 10px auto 0 auto;
        width: 150px;
        height: 150px;
        padding-left: 0;
    }
    .online-safety__card__icon__image-for-phone {
        display: none;
        visibility: hidden;
    }
    .online-safety__card__icon__image-for-desktop {
        display: initial;
        visibility: initial;
    }

    .online-safety__card__icon.online-safety__card__device_icon {
        margin: 37px auto 0 auto;
    }
       
    .online-safety__card__icon img {
        
        height: 100%;
        width: 150px;
        height: 150px;
        max-width: 150px;
        max-height: 150px;
    }

    .online-safety__card__subheading {
        
        margin-bottom: auto;
    }
}

.online-safety__info {
    margin: 0 0 28px 0;
    background: #e0eefb;
    padding: 12px;
    display: block;
    float: left;
    width: 100%;
    margin-top: 8px;
}
@media (min-width: 768px) {
    .online-safety__info {
    }
}

.online-safety__info-icon {
    display: block;
    height: 40px;
    width: 40px;
    border-radius: 20px;
    float:left; 
    margin-right:12px;
    background-image: url(/customer/resources/images/online-safety/information.svg);
    background-repeat: no-repeat;
    background-position: center;
    background-color: #0074e0;
}

.online-safety__info-content {
    display: inline-block;
    float: left;
    width: calc(100% - 52px);
}

.online-safety__info-heading {
    margin-top: 10px;
    color: #575252;
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-size: 16px;
    line-height: 20px;
}

.online-safety__info-text {
    color: #575252;
    font-weight: 400;
    font-size: 16px;
    line-height: 20px;
}

.online-safety__info-text a,
.online-safety__info-text a::visited {
    color: #00539f !important;
}

.online-safety__info-text-anchor {
    color: #0074e0;
    text-decoration: underline;
}


.online-safety__section-divider {
    margin: 15px 0;
    border-top: 1px solid #e5e5e5;
}
.online-safety__section-divider--narrow {
    max-width: 606px;
    margin: 0 auto;
}

.online-safety__section-divider--hide-for-desktop {
    margin: 8px auto 16px auto;
}
@media (min-width: 768px) { 
    .online-safety__section-divider--hide-for-desktop {
        display: none;
    }
}
/* //////////////////////////////////////////// */

.online-safety__section-divider--accordian {
    margin-bottom: 40px;
    margin-top: 24px;
}

.online-safety__help-accordian-title {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-size: 20px;
    color: #575252;
    line-height: 24px;
    margin-top: 24px;
    margin-bottom: 14px;
}

.online-safety__help-accordian-subtitle {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-size: 18px;
    color: #575252;
    line-height: 20px;
    margin-bottom: 16px;
}


.online-safety__help-accordian-h6 {
    font-weight: 400;
    font-size: 16px;
    font-weight: 700;
    font-family: 'tesco', Tahoma,sans-serif !important;
    color: #575252;
    line-height: 22px;
    margin-bottom: 12px;
    margin-top: 16px;
}

.online-safety__help-accordian-bold {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
}

.online-safety__help-accordian-columns {
    display: flex;
}
.online-safety__help-accordian-column {
    width: 50%;
}

.online-safety__help-accordian-columns {
    display: flex;
    flex-flow: column;
     margin-bottom: 36px;
}
@media (min-width: 768px) {
    .online-safety__help-accordian-columns {
        flex-flow: row;
    }
}
.online-safety__help-accordian-column {
    width: 100%;
}
@media (min-width: 768px) {
    .online-safety__help-accordian-column {
        width: 50%;
    }
}

.online-safety__help-accordian-column:first-of-type {
    border-right: 1px solid #e5e5e5;
    margin-right: 16px;
    padding-right: 16px;
}
@media (min-width: 768px) {
    .online-safety__help-accordian-column:first-of-type {
        border-right: initial !important;
    }
}
.online-safety__help-accordian__ol {
    list-style: auto;
    padding-left: 19px;
}

.online-safety__help-accordian__ol:first-of-type { 
    margin-bottom: 16px;
    padding-bottom: 16px;
    border-bottom: 1px solid #e5e5e5;
}

.online-safety__help-accordian__ol li {
    margin-bottom: 8px;
}
.online-safety__help-accordian__ol:last-of-type {
    margin-bottom: 8px;
    margin-bottom: 36px;
}
.online-safety__icon-pairing {
    margin-bottom: 16px;
}

.online-safety__icon-pairing img {
    height: 40px;
    width: 40px;
    float: left;
    margin-right: 12px;
    margin-bottom: 20px;
}

.online-safety__icon-pairing-heading {
   font-size: 16px; 
   line-height: 20px; 
   font-weight: 700; 
   color: #575252; 
   font-family: 'tesco', Tahoma,sans-serif !important;
   margin-bottom: 4px;
}

.online-safety__icon-pairing-text {
    font-size: 16px;
    line-height: 24px;
    font-weight: 400;
    color: #575252;
}

.online-safety__not-sure-accordian {
    max-width: 606px;
    margin: 0 auto;
    padding: 0 12px;
}

.online-safety__not-sure-accordian.online-safety__not-sure-accordian--full-width {
    margin-top: -16px;
    margin-bottom: -24px;
}


.online-safety__device-guide__show-more {
    margin: 0;
}
.online-safety__not-sure-accordian-trigger:focus,
.online-safety__not-sure-accordian-trigger:active,
.online-safety__not-sure-accordian-trigger:hover,
.online-safety__not-sure-accordian-trigger {
    padding: 0;
    border: initial;
    position: flex;
    text-align: left;
    position:relative;
    background: transparent;
    color: inherit;
    padding-right: 28px;
    width: 100%;
}
.online-safety__not-sure-accordian-title {
    border: none;
    color: #00539f;
    font-weight: 400;
    margin-top: 12px;
    margin-bottom: 12px;
    display:inline-block;
}


.online-safety__not-sure-accordian-title h3 {
    margin: 0;
}

.online-safety__not-sure-accordian-chevron {
    height: 12px;
    width: 20px;
    display: inline-block;
    background-image: url(/customer/resources/images/online-safety/blue-chevron.svg);
    background-repeat: no-repeat;
    margin-left: 8px;
    transform: rotate(180deg);
}
.online-safety__not-sure-accordian-trigger[aria-expanded="true"] .online-safety__not-sure-accordian-chevron {
    transform: rotate(0deg);
}


.online-safety__not-sure-accordian--full-width .online-safety__not-sure-accordian-title {
    width: 100%;
}

.online-safety__not-sure-accordian--full-width .online-safety__not-sure-accordian-chevron {
    position: absolute;
    top: 18px;
}

.online-safety__device-hero {
    width: 100%;
    background: none;
    border: none;
    color: #575252;
}
@media (min-width: 768px) {
    .online-safety__device-hero {
        background-image: url('/customer/resources/images/online-safety/hero-image.jpg');
        background-size: cover;
        background-position: center;
        padding-top:clamp(49px, 1vw, 122px);
        padding-bottom:49px;
        padding-left:clamp(32px, 2vw, 54px);
    }
}

.online-safety__device-hero .online-safety__h1-style {
    color: #575252; 
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-size: 32px;
    line-height: 108%;
    text-align: center;
    margin: 0 0 20px;
    margin-bottom: 16px;
    margin-top: 16px;
}
@media (min-width: 768px) {
    .online-safety__device-hero .online-safety__h1-style {
        font-size: clamp(40px, 5.5vw, 72px);
        color: #ffffff; 
        text-align: left;
        max-width: 540px;
        width: 40.5vw;
    }
}

.online-safety__device-hero .online-safety__p-regular {
    color: #575252;
    font-weight: 400;
    font-size: 16px;
    line-height: 108%;
    text-align: center;
    margin: 0;
}
@media (min-width: 768px) {
    .online-safety__device-hero .online-safety__p-regular {
        font-size: clamp(24px, 2.3vw, 38px);
        color: #ffffff; 
        text-align: left;
        max-width: 500px;
        width: 31.5vw;
    }
}

.online-safety__quick_guidance-h3 {
    text-align: center;
    font-size: 16px;
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    line-height: 20px;
    margin-bottom: 16px;
    margin-top: 36px;
}

.online-safety__quick_guidance {
    display: flex;
    gap: 16px;
    flex-wrap: wrap;
    justify-content: center;
    margin-bottom: 24px;
}

@media (min-width: 768px) {
    .online-safety__quick_guidance {
        margin-bottom: 40px;
    }
}

.online-safety__quick_guidance a {
    text-decoration: none;
    background: #ffffff;
    padding: 8px 16px  8px 16px;
    border-radius: 4px;
    box-shadow: 0px 2px 4px 0px #00000026;
    flex-basis: calc(50% - 8px);
}
@media (min-width: 768px) {
    .online-safety__quick_guidance a {
        box-shadow: initial;
        width: 200px;
        flex-wrap:nowrap;
        flex-basis: 200px;
        position: relative;
        padding: 16px 16px 52px 16px;

    }
}
.online-safety__quick_guidance a:hover {
    text-decoration: none;
}

.online-safety__quick_guidance h4 {
    font-weight: 700;
    line-height: 20px;
    font-size: 14px;
    color: #575252;
    margin-bottom: 4px;
    text-decoration: none !important;
    padding-top: 0;
    text-align: center;
    margin: 0;
    margin-bottom: 8px;
}
.online-safety__quick_guidance a:hover h4 {
    text-decoration: none !important;
}
@media (min-width: 768px) {
    .online-safety__quick_guidance h4 {
        text-align: left;
    }
}

.online-safety__quick_guidance h5 {
    font-weight: 400;
    line-height: 20px;
    font-size: 14px;
    color: #575252;
    text-decoration: none !important;
    text-align: center;
    margin: 0;
}
.online-safety__quick_guidance a:hover h5 {
    text-decoration: none !important;
}
@media (min-width: 768px) {
    .online-safety__quick_guidance h5 {
        text-align: left;
    }
}

.online-safety__quick_guidance h6 {
    font-weight: 400;
    line-height: 20px;
    font-size: 14px;
    color: #00539f;
    display: none;
    text-align: right;
    position: absolute;
    bottom: 0px;
    right:16px;
    text-decoration: none;
    width: 100%;
  text-align: center;
}
.online-safety__quick_guidance a:hover h6 {
    text-decoration: underline !important;
}
@media (min-width: 768px) {
    .online-safety__quick_guidance h6 {
        display: block;
    }
}

.online-safety__sense-check-h3 {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    line-height: 24px;
    font-size: 20px;
    color: #575252;
    text-align: center;
    margin-bottom: 8px;
    position: relative;
    z-index:9;
}

.online-safety__sense-check-p {
    font-weight: 400;
    line-height: 24px;
    font-size: 16px;
    color: #575252;
    text-align: center;
    margin-bottom: 24px;
    position: relative;
    z-index:9;
}

.online-safety__sense-check-p a,
.online-safety__sense-check-p a::visited {
    color: #00539f !important;
}

.online-safety__sense-check {
    display: flex;
    flex-wrap: wrap;
    margin-bottom: 32px;
}
@media (min-width: 768px) {
    .online-safety__sense-check{
        flex-wrap: nowrap;
    }
}

.online-safety__sense-check article { 
    flex-basis: 100%;
}

.online-safety__sense-check table {  
    width:100%; 
    table-layout: fixed;
    border: 1px solid #d3d3d3;
    margin-bottom: 8px;
    
    box-sizing: border-box;
    border-collapse: separate; /* This line */
}
.online-safety__sense-check article:last-of-type table {
    border-right: 1px solid #d3d3d3;
}

.online-safety__sense-check article:last-of-type table a,
.online-safety__sense-check article:last-of-type table a::visited {
    color: #00539f !important;
}

@media (min-width: 768px) {
    .online-safety__sense-check table {
        border-right: 0;
    }
    .online-safety__sense-check article:last-of-type table {
        border-right: 1px solid #d3d3d3;
    }
}
.online-safety__sense-check tr {
    background: #ffffff;
}

@media (min-width: 768px) {
    .online-safety__sense-check tr:nth-child(2) {   
        height: 101px;
    }
    .online-safety__sense-check tr:nth-of-type(3) {   
        height: 101px;
    }
    .online-safety__sense-check tr:nth-of-type(4) {   
        height: 124px;
    }
    .online-safety__sense-check tr:nth-of-type(6) {   
        height: 100px;
    }
}


.online-safety__sense-check th {   
    font-weight:bold;  
    word-wrap: break-word;
}
.online-safety__sense-check td {
    word-wrap: break-word;
}

.online-safety__sense-check tr:first-of-type th { 
    background: #e5e5e5; 
    padding: 16px 24px; 
}

.online-safety__sense-check tr {
    position: relative;
    padding: 16px 24px; 
}

.online-safety__sense-check tr:not(:first-of-type) th {
    width: 50%; 
    padding: 8px 8px 8px 24px;
    position: relative;
    vertical-align: top;
}

.online-safety__sense-check tr:not(:first-of-type) td {
    width: 50%;
    padding: 8px 24px 8px 8px;
    position: relative;
    vertical-align: top;
}

.online-safety__sense-check tr:last-of-type td {
    text-align: center;

}

.online-safety__sense-check tr:not(:first-of-type, :last-of-type) th::after {
    width: calc(100% - 16px);
    border-bottom: 1px solid #e5e5e5;
    content: '';
    display: inline-block;
    position: absolute;
    bottom: 0;
    right: 0;
}
.online-safety__sense-check tr:not(:first-of-type, :last-of-type) td::after {
    width: calc(100% - 24px);
    border-bottom: 1px solid #e5e5e5;
    content: '';
    display: inline-block;
    position: absolute;
    bottom: 0;
    left: 0;
}

.online-safety__device-guide {
    background: #ffffff;
    padding: 24px;
    margin-bottom: 24px;
}

.online-safety__device__guide.hsim-scen-main-container > div {
    overflow: hidden;
/*    margin-top: -40px;*/
}

.online-safety__device__guide.hsim-scen-main-container .scen-data-header.navigation {
    font-size: 20px;
}

.online-safety__device-guide:last-of-type {
    margin-bottom: 40px;
}

.online-safety__device-guide__icon {
    width: 48px;
    height: 48px;
    padding: 11px 12px;
    color: #ffffff;
    border-radius: 24px;
    background-color: #00539f;
    display:block;
    text-align: center;
    margin-bottom: 8px;
}
@media (min-width: 768px) {
    .online-safety__device-guide__icon {
        position: absolute;
        margin-bottom: 0px;
    }
}

.online-safety__device-guide__h3 {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    color: #575252;
    font-size: 24px;
    line-height: 28px;
    margin-top: 0;
    margin-bottom: 8px;
}
@media (min-width: 768px) {
    .online-safety__device-guide__h3 {
        margin-left: 60px;
    }
}

.online-safety__device-guide__p {
    font-weight: 400;
    color: #575252;
    font-size: 16px;
    line-height: 24px;
    margin-bottom: 24px;
        margin-top: 0;
}
@media (min-width: 768px) {
    .online-safety__device-guide__p {
        margin-left: 60px;
    }
}

.online-safety__device__guide-cards{
    background: #f6f6f6;
    padding: 16px;
    display: flex;
    gap: 16px;
    flex-wrap: wrap;
    flex-direction: column;
}
@media (min-width: 768px) {
    .online-safety__device__guide-cards {
        flex-direction: row;
    }
}

.online-safety__device__guide-cards li {
    background: #ffffff;
    padding: 16px 16px 64px 16px;
    flex-basis: calc(50% - 8px);
    position: relative;
    margin: 0;
    display: flex;
    flex-direction: column;+
}

.online-safety__device__guide-cards li h4 {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    color: #575252;
    font-size: 20px;
    line-height: 24px;
    margin-bottom: 8px;
    margin-top: 0;
}

.online-safety__device__guide-cards li h5 {
    font-weight: 400;
    color: #575252;
    font-size: 16px;
    line-height: 24px;
    margin-top: 0;
}

.online-safety__device__guide-cards li a {
    margin-top: 16px;
    background-color: #00539f;
    color: #ffffff;
    font-weight: 700;
    font-family: 'tesco', Tahoma,sans-serif !important;
    font-size: 16px;
    line-height: 24px;
    padding: 8px 18px;
    border-radius: 200px;
    float: right;
    position: absolute;
    right: 16px;
    bottom: 16px;
}
.online-safety__device__guide-cards li a:hover,
.online-safety__device__guide-cards li a:focus {
    box-shadow: 0 0 0 4px #00539f66;
}
.online-safety__device__guide-cards li a:visited {
    color: #ffffff !important;
}


.online-safety__device__guide-container {
    border: 16px solid #f6f6f6 ;
    padding: 16px;
    width: 100%;
    min-height:20px;
    background: #ffffff;
    display: none;
    min-height: 368px;
}

@media (min-width: 768px) {
    .online-safety__device__guide-container.online-safety__device__guide-container--hsim-activated {
        margin-bottom: 28px;
    }
}

.online-safety__device__guide .scen-data-container {
/*    padding-top: 32px; */
}



.online-safety__device__guide__close-button,
.online-safety__device__guide__close-button:visited {
    margin-top: 16px;
    height: 24px;
    font-size: 16px; 
    line-height: 24px;
    font-weight: 700;
    font-family: 'tesco', Tahoma,sans-serif !important;
    margin-bottom: 16px;
    display: block;

}
.online-safety__device__guide__close-button:before {
    content: '';
    display: block;
    width: 24px;
    height: 24px;
    background-image: url('/customer/resources/images/online-safety/left-chevron.svg');
    background-repeat: no-repeat;
    float:left;
    background-position: center center;
}

@media (max-width: 768px) {
    .online-safety__device__guide__close-button,
    .online-safety__device__guide__close-button:visited {
        margin-top: 0;
        height: 40px;
        width: 100%;
        margin-bottom: 0;
    }

    body.online-safety__device__body--modal {
        overflow:hidden;
    }
    .online-safety__device__guide-container {
        display: none;
        position: fixed;
        top: 0;
        bottom: 0;
        left: 0;
        right: 0;
        border: black;
        background: #ffffff;
        z-index: 99999;
        overflow: scroll;
    }

    .online-safety__device__guide-container scen-data-header {
        color: green;
    }
    .online-safety__device__guide-container .scen-header-go-back {
        display:none !important;
    }
    .online-safety__device__guide__close-button {
        font-size:0px;
    }
     .online-safety__device__guide__close-button::before {
     display: none;
     }
    .online-safety__device__guide__close-button::after {
        content: '';
        display: block;
        background: url('/customer/resources/images/online-safety/close.svg');
        height: 20px;
        width: 20px;
        float: right;
        margin: 10px;
    }
}

.online-safety__device__guide-related-tabs {
    margin-top: 14px;
}

.online-safety__device__guide-related-tabs ul {
    display: flex;
    flex-wrap: wrap;
    margin-bottom: 0;
}

.online-safety__device__guide-related-tabs ul li {
    gap: 6px;

}

.online-safety__device__guide-related-tabs ul li a:visited,
.online-safety__device__guide-related-tabs ul li a:focus,
.online-safety__device__guide-related-tabs ul li a {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-style: 700;
    font-size: 16px;
    line-height: 24px;
    color: #00539f !important;
    text-align: center;
    padding: 6px 8px 6px;
    border-bottom: 4px solid #ffffff; 
    display:block;
}

.online-safety__device__guide-related-tabs ul li a.active-tab {
    border-bottom: 4px solid var(--Brand-Blue, #00539F); 
}

.online-safety__device__guide-related-tabs--hidden {
    display: none;
}

.online-safety__device__guide-related-tabs--hidden-tab__link {
}

.online-safety__feedback .feedback-rating-container {
    text-align:center;

}
.online-safety__feedback .feedback-rating-container h3 {
    font-weight: 700;
   font-family: 'tesco', Tahoma,sans-serif !important;
    font-style: Bold;
    font-size: 20px;
    line-height: 24px;
    letter-spacing: 0px;
    text-align: center;
    margin-top: 8px;
    margin-bottom: 16px;
}
.online-safety__feedback .feedback-rating-container svg {
    scale: 1.2;
}

.online-safety__device__guide hsim-scen-main-container {
    margin-top: 40px;
}

#articleFeedbackContainer {
    margin-top: 0;
    padding-top: 0;
}

@media (min-width: 768px) {
    .online-safety__sense-check > article {
        padding-top: 120px;
        margin-top: -120px;
    }
}
